@@ -643,6 +643,8 @@ Image::PixelFormatType Image::PixelFormat() const
   }
   else if (type == FIT_RGB16)
     fmt = RGB_INT16;
+  else if (type == FIT_RGBA16)
+    fmt = RGBA_INT16;
   else if (type == FIT_RGBF)
     fmt = RGB_FLOAT32;
   else if (type == FIT_UINT16 || type == FIT_INT16)
